==> xapi-schema-0.1.0.jar: i18n/dict.clj <==
{:en {:not "not"
      :missing-required-key "Missing required key"
      :disallowed-key "Key not allowed"
      :threw "threw"
      :sequential "sequential"
      :map "map"
      :integer "integer"
      :string "string"
      :number "number"
      :boolean "boolean"
      :in "in"
      :present "present"
      :predicates
      {:revision-not-allowed "valid if Statement object is an Activity"
       :platform-not-allowed "valid if Statement object is an Activity"
       :no-multi-ifi "there is at most one IFI"
       :no-ifi "present: IFI"
       :no-anon-group-member "present: member key on anonymous group"
       :distinct-ic-ids "distinct: Interaction Component IDs"
       :valid-component-keys  "valid Interaction Component List key(s)"
       :score-lt-max "less than max"
       :score-gt-min "greater than min"
       :valid-ltag "a valid RFC 5646 Language Tag"
       :valid-iri "a valid IRI address"
       :valid-mailto-iri "a valid MailTo IRI address"
       :valid-irl "a valid IRL"
       :valid-openid "a valid OpenID URL"
       :valid-uuid "a valid Uuid"
       :valid-timestamp "a valid ISO 8601 timestamp"
       :valid-duration "a valid ISO 8601 duration"
       :valid-xapi-version "a valid xAPI 1.x.x version"
       :valid-sha-2-sum "a valid SHA-2 sum"
       :valid-sha-1-sum "a valid SHA-1 sum"
       :exactly-2-members "Exactly 2 Members"
       :at-least-one-agent "at least one Agent"
       :at-least-one-activity "at least one Activity"
       :at-least-one-attachment "at least one Attachment"
       :one-oauth-consumer "one OAuth Consumer"
       :at-least-one-statement "at least one statement"}}}

==> xapi-schema-0.1.7-20160105.174046-2.jar: i18n/dict.clj <==
{:en {:not "not"
      :missing-required-key "Missing required key"
      :disallowed-key "Key not allowed"
      :threw "threw"
      :sequential "sequential"
      :map "map"
      :integer "integer"
      :string "string"
      :number "number"
      :boolean "boolean"
      :in "in"
      :present "present"
      :predicates
      {:revision-not-allowed "valid if Statement object is an Activity"
       :platform-not-allowed "valid if Statement object is an Activity"
       :no-multi-ifi "there is at most one IFI"
       :no-ifi "present: IFI"
       :no-anon-group-member "present: member key on anonymous group"
       :distinct-ic-ids "distinct: Interaction Component IDs"
       :valid-component-keys  "valid Interaction Component List key(s)"
       :score-lt-max "less than max"
       :score-gt-min "greater than min"
       :valid-ltag "a valid RFC 5646 Language Tag"
       :valid-iri "a valid IRI address"
       :valid-mailto-iri "a valid MailTo IRI address"
       :valid-irl "a valid IRL"
       :valid-openid "a valid OpenID URL"
       :valid-uuid "a valid Uuid"
       :valid-timestamp "a valid ISO 8601 timestamp"
       :valid-duration "a valid ISO 8601 duration"
       :valid-xapi-version "a valid xAPI 1.x.x version"
       :valid-sha-2-sum "a valid SHA-2 sum"
       :valid-sha-1-sum "a valid SHA-1 sum"
       :exactly-2-members "Exactly 2 Members"
       :at-least-one-agent "at least one Agent"
       :at-least-one-activity "at least one Activity"
       :at-least-one-attachment "at least one Attachment"
       :one-oauth-consumer "one OAuth Consumer"
       :at-least-one-statement "at least one statement"
       :void-statement-ref "a valid voiding statement with objectType StatementRef"}}}
